==> klayout-0.15.tar.gz: klayout-0.15/src/layProgressWidget.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "layProgressWidget.h"

#include <math.h>

namespace lay
{

// --------------------------------------------------------------------

class ProgressBarWidget
  : public QWidget 
{
public:
  ProgressBarWidget (QWidget *parent, const char *name = "");

  void set_value (double v, const std::string &value);

  QSize sizeHint () const 
  {
    return QSize (m_width, 1);
  }

  QSize minimumSizeHint () const 
  {
    return QSize (m_width, 1);
  }

private:
  double m_value;
  std::string m_value_string;
  int m_width;
  int m_length;
  int m_fw;
  int m_bw;

  void paintEvent (QPaintEvent *event); 
  void resizeEvent (QResizeEvent *event); 
};

ProgressBarWidget::ProgressBarWidget (QWidget *parent, const char *name)
  : QWidget (parent, name),
    m_value (0.0), m_width (64), m_length (0), m_fw (1), m_bw (0)
{
  // .. nothing yet ..
}

void
ProgressBarWidget::set_value (double v, const std::string &value)
{
  if (value != m_value_string) {
    update ();
    m_value_string = value;
  }

  m_value = v;
  int l = int (floor ((v < 0.0 ? 0.0 : v) * 0.01 * (double (m_width - 2) - 1e-6))) % m_width;
  if (l != m_length) {
    m_length = l;
    update ();
  }
}

void 
ProgressBarWidget::paintEvent (QPaintEvent *event)
{
  QPainter painter (this);

  painter.fillRect (QRect (QPoint (m_fw, m_fw), QPoint (m_length + m_fw - 1, height () - 2 - m_fw)), palette ().brush (QPalette::Highlight));
  painter.fillRect (QRect (QPoint (m_length + m_fw, m_fw), QPoint (width () - m_fw, height () - 2 - m_fw)), palette ().brush (QPalette::Base));
  painter.setPen (palette ().color (QPalette::Text));
  
  for (int d = 0; d < m_bw; ++d) {
    painter.drawRect (QRect (QPoint (d, d), QPoint (width () - 2 - d, height () - 2 - d)));
  }

  painter.setFont (font ());

  painter.setClipRect (QRect (QPoint (m_fw, m_fw), QPoint (m_length + m_fw - 1, height () - 1 - m_fw)));
  painter.setPen (palette ().color (QPalette::HighlightedText));
  painter.drawText (rect (), Qt::AlignHCenter | Qt::AlignVCenter, m_value_string.c_str ());

  painter.setClipRect (QRect (QPoint (m_length + m_fw, 0), QPoint (width () - m_fw, height () - 1 - m_fw)));
  painter.setPen (palette ().color (QPalette::Text));
  painter.drawText (rect (), Qt::AlignHCenter | Qt::AlignVCenter, m_value_string.c_str ());
}

void
ProgressBarWidget::resizeEvent (QResizeEvent *event)
{
  m_width = size ().width ();
  update ();
}

// --------------------------------------------------------------------

ProgressWidget::ProgressWidget (ProgressReporter *pr, QWidget *parent, const char *name)
  : QFrame (parent, name),
    mp_pr (pr)
{
  int button_size = 12;

  QHBoxLayout *layout = new QHBoxLayout (this);
  layout->setSpacing (4);
  layout->setMargin (0);

  layout->addSpacing (4);

  mp_label = new QLabel (this);
  layout->addWidget (mp_label, 1);

  mp_progress_bar = new ProgressBarWidget (this);
  layout->addWidget (mp_progress_bar);

  mp_cancel_button = new QToolButton (this);
  mp_cancel_button->setMaximumSize (QSize (button_size, button_size));
  layout->addWidget (mp_cancel_button);

  layout->addSpacing (4);

  connect (mp_cancel_button, SIGNAL (clicked ()), this, SLOT (signal_break ()));
}

void 
ProgressWidget::set_text (const std::string &text)
{
  mp_label->setText (text.c_str ());
}

void 
ProgressWidget::set_value (double v, const std::string &value)
{
  mp_progress_bar->set_value (v, value);
}

void 
ProgressWidget::signal_break ()
{
  mp_pr->signal_break ();
}

}

==> klayout-0.21.19.tar.gz: klayout-0.21.19/src/layProgressWidget.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "layProgressWidget.h"

#include <math.h>

namespace lay
{

// --------------------------------------------------------------------

class ProgressBarWidget
  : public QWidget 
{
public:
  ProgressBarWidget (QWidget *parent, const char *name = "");

  void set_value (double v, const std::string &value);

  QSize sizeHint () const 
  {
    return QSize (m_width, 1);
  }

  QSize minimumSizeHint () const 
  {
    return QSize (m_width, 1);
  }

private:
  double m_value;
  std::string m_value_string;
  int m_width;
  int m_length;
  int m_fw;
  int m_bw;

  void paintEvent (QPaintEvent *event); 
  void resizeEvent (QResizeEvent *event); 
};

ProgressBarWidget::ProgressBarWidget (QWidget *parent, const char *name)
  : QWidget (parent, name),
    m_value (0.0), m_width (64), m_length (0), m_fw (1), m_bw (0)
{
  // .. nothing yet ..
}

void
ProgressBarWidget::set_value (double v, const std::string &value)
{
  if (value != m_value_string) {
    update ();
    m_value_string = value;
  }

  m_value = v;
  int l = int (floor ((v < 0.0 ? 0.0 : v) * 0.01 * (double (m_width - 2) - 1e-6))) % m_width;
  if (l != m_length) {
    m_length = l;
    update ();
  }
}

void 
ProgressBarWidget::paintEvent (QPaintEvent *event)
{
  QPainter painter (this);

  int right = width ();
  int bottom = height ();

  painter.fillRect (QRect (QPoint (m_fw, m_fw), QPoint (m_length + m_fw - 1, bottom - 1 - m_fw)), palette ().brush (QPalette::Highlight));
  painter.fillRect (QRect (QPoint (m_length + m_fw, m_fw), QPoint (right - 1 - m_fw, bottom - 1 - m_fw)), palette ().brush (QPalette::Base));
  painter.setPen (palette ().color (QPalette::Text));
  
  for (int d = 0; d < m_bw; ++d) {
    painter.drawRect (QRect (QPoint (d, d), QPoint (right - 1 - d, bottom - 1 - d)));
  }

  painter.setFont (font ());

  painter.setClipRect (QRect (QPoint (m_fw, m_fw), QPoint (m_length + m_fw - 1, bottom - m_fw)));
  painter.setPen (palette ().color (QPalette::HighlightedText));
  painter.drawText (rect (), Qt::AlignHCenter | Qt::AlignVCenter, m_value_string.c_str ());

  painter.setClipRect (QRect (QPoint (m_length + m_fw, 0), QPoint (right - m_fw, bottom - m_fw)));
  painter.setPen (palette ().color (QPalette::Text));
  painter.drawText (rect (), Qt::AlignHCenter | Qt::AlignVCenter, m_value_string.c_str ());
}

void
ProgressBarWidget::resizeEvent (QResizeEvent *event)
{
  m_width = size ().width ();
  update ();
}

// --------------------------------------------------------------------

ProgressWidget::ProgressWidget (ProgressReporter *pr, QWidget *parent, const char *name)
  : QFrame (parent, name),
    mp_pr (pr)
{
  QVBoxLayout *top_layout = new QVBoxLayout (this);

  top_layout->addStretch (1);
  QHBoxLayout *layout = new QHBoxLayout (top_layout);
  top_layout->addStretch (1);

  layout->setSpacing (4);
  layout->setMargin (0);

  layout->addStretch (1);

  mp_label = new QLabel (this);
  layout->addWidget (mp_label);

  layout->addSpacing (8);

  QFrame *progress_bar_frame = new QFrame (this);
  progress_bar_frame->setFrameStyle (QFrame::Box | QFrame::Plain);
  layout->addWidget (progress_bar_frame, 2);

  QHBoxLayout *pbf_layout = new QHBoxLayout (progress_bar_frame);
  progress_bar_frame->setLayout (pbf_layout);
  pbf_layout->setMargin (0);

  mp_progress_bar = new ProgressBarWidget (progress_bar_frame);
  pbf_layout->addWidget (mp_progress_bar);

  layout->addSpacing (8);

  mp_cancel_button = new QToolButton (this);
  mp_cancel_button->setText (tl::translate ("Cancel").c_str ());
  layout->addWidget (mp_cancel_button);

  layout->addStretch (1);

  connect (mp_cancel_button, SIGNAL (clicked ()), this, SLOT (signal_break ()));
}

void 
ProgressWidget::set_text (const std::string &text)
{
  mp_label->setText (text.c_str ());
}

void 
ProgressWidget::set_value (double v, const std::string &value)
{
  mp_progress_bar->set_value (v, value);
}

void 
ProgressWidget::signal_break ()
{
  mp_pr->signal_break ();
}

}
